aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/finder.php
diff options
context:
space:
mode:
authorEtienne Baroux <barouxe@phelma.grenoble-inp.fr>2014-06-02 10:12:18 +0200
committerTristan Darricau <github@nicofuma.fr>2016-12-03 16:37:35 +0100
commit346f31a03156839d1b1931d2fc69cd2ab5656bc0 (patch)
treeaed312ce3f9e890a260a02132119cdfff8764d9b /phpBB/phpbb/finder.php
parent17e8726582df3e3115893668c7b1ea39b87028ba (diff)
downloadforums-346f31a03156839d1b1931d2fc69cd2ab5656bc0.tar
forums-346f31a03156839d1b1931d2fc69cd2ab5656bc0.tar.gz
forums-346f31a03156839d1b1931d2fc69cd2ab5656bc0.tar.bz2
forums-346f31a03156839d1b1931d2fc69cd2ab5656bc0.tar.xz
forums-346f31a03156839d1b1931d2fc69cd2ab5656bc0.zip
[ticket/12610] Add command to check if the board is up to date.
PHPBB3-12610
Diffstat (limited to 'phpBB/phpbb/finder.php')
-rw-r--r--phpBB/phpbb/finder.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/phpBB/phpbb/finder.php b/phpBB/phpbb/finder.php
index 58bc27084e..1f1d931880 100644
--- a/phpBB/phpbb/finder.php
+++ b/phpBB/phpbb/finder.php
@@ -50,12 +50,12 @@ class finder
*
* @param \phpbb\filesystem\filesystem_interface $filesystem Filesystem instance
* @param string $phpbb_root_path Path to the phpbb root directory
* @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
* @param string $php_ext php file extension
* @param string $cache_name The name of the cache variable, defaults to
* _ext_finder
*/
- public function __construct(\phpbb\filesystem\filesystem_interface $filesystem, $phpbb_root_path = '', \phpbb\cache\driver\driver_interface $cache = null, $php_ext = 'php', $cache_name = '_ext_finder')
+ public function __construct(\phpbb\filesystem\filesystem_interface $filesystem, $phpbb_root_path = '', \phpbb\cache\service $cache = null, $php_ext = 'php', $cache_name = '_ext_finder')
{
$this->filesystem = $filesystem;
$this->phpbb_root_path = $phpbb_root_path;
@@ -50,12 +50,12 @@ class finder
* @param \phpbb\filesystem\filesystem_interface $filesystem Filesystem instance
* @param string $phpbb_root_path Path to the phpbb root directory
- * @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
+ * @param \phpbb\cache\service $cache A cache instance or null
* @param string $php_ext php file extension
* @param string $cache_name The name of the cache variable, defaults to